# -*- coding: utf-8 -*-
import scrapy, re
from tribunaCampeche.items import NoticiasItem

"""
MEDIO:
Tribuna, Campeche
USO:
scrapy crawl noticias --nolog -s filename=2018-08-10.json -a year=2018 -a month=8 -a day=10
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year  = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day   = getattr(self, "day", None)

        self.baseURL = "http://tribunacampeche.com/" + year + "/" + month + "/" + day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
        
        pagination = response.xpath('//a[@class="page-numbers"]/@href').extract()
        if pagination is not None and len(pagination) > 0:
            pages = pagination[-1].rstrip("/")
            pages = int(pages[pages.rfind("/") + 1:])

            for page in range(1, pages):
                yield scrapy.Request(url=self.baseURL+"/page/"+str(page + 1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.css('div.vw-post-box').css('div.vw-post-box-inner').xpath('./h3/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        # La fecha obtenida ya incluye formato y zona horaria
        item['date']  = response.xpath('//time[@itemprop="datePublished"]/@datetime').extract_first()
        item['title'] = remove_tags(response.xpath('//h1[@class="entry-title"]').extract_first())
        
        try:
            topic = remove_tags(response.css('article.vw-main-post').xpath('./div[@class="vw-post-categories"]/div/a').extract_first())
        except:
            topic = None
        
        item['topic'] = topic

        for p in response.css('div.vw-post-content').css('p').extract():
            text += remove_tags(p) + "\n"
        
        item['text'] = text

        item['url'] = response.url

        yield item
